@@ -332,6 +332,7 @@ def sqrt_scaler(value):
         return [ item*scale if item is not None else None for item in value ]
     return func
 
+
 @config.Int_flag('transpose', 'Transpose instrument by this many semitones.')
 class Instrument_designer(config.Action_with_output_dir):
     instrument_class = Instrument
@@ -415,9 +416,9 @@ class Instrument_designer(config.Action_with_output_dir):
     def initial_hole_diameter_fractions(self):
         return [ 0.75 ] * self.n_holes
 
-    @property
-    def hole_extra_height_by_diameter(self):
-        return [ 0.0 ] * self.n_holes
+    #@property
+    #def hole_extra_height_by_diameter(self):
+    #    return [ 0.0 ] * self.n_holes
 
     @property
     def initial_state_vec(self):
@@ -493,8 +494,8 @@ class Instrument_designer(config.Action_with_output_dir):
             shift = math.sin(radians) * thickness
             inst.inner_hole_positions[i] = inst.hole_positions[i] + shift
             inst.hole_lengths[i] = (
-                math.sqrt(thickness*thickness+shift*shift) +
-                self.hole_extra_height_by_diameter[i] * inst.hole_diameters[i]
+                math.sqrt(thickness*thickness+shift*shift) 
+                #+ self.hole_extra_height_by_diameter[i] * inst.hole_diameters[i]
             )
         
         inst.inner_kinks = inner_kinks
@@ -766,6 +767,20 @@ class Instrument_designer(config.Action_with_output_dir):
         #print(self._opt_score(state_vec))
 
 
+def bore_scaler(value):
+    @property
+    def func(self):
+        scale = math.sqrt(self.scale) * self.bore_scale
+        return [ item*scale if item is not None else None for item in value ]
+    return func
+
+@config.Float_flag('bore_scale',
+    'Bore diameter is scaled as the square root of the instrument size times this amount.'
+    )
+class Instrument_designer_with_bore_scale(Instrument_designer):
+    bore_scale = 1.0
+
+
 def load(output_dir):
     with open(os.path.join(output_dir, 'data.pickle'), 'rb') as f:
         if sys.version_info.major == 3:
